Last Updated on May 18, 2026

Reliable Embedded Systems – Robert Berger e.U. build framework & bitbake-setup/whinlatter on phyBOARD®-Pollux i.MX 8M Plus

Key Takeaways

  • The article discusses how to use bitbake-setup and whinlatter on the phyBoard®-Pollux i.MX 8M Plus, especially after the poky repository master branch is not being updated anymore.
  • It outlines the installation of a minimal build framework and the necessary steps to set up Docker and manage project directories.
  • Users need to download the BitBake repository and start the Docker build container to proceed with bitbake-setup.
  • Key actions include initializing bitbake-setup, building the phytec-headless-image, and flashing the SD card for the board.
  • The conclusion emphasizes the transition from a custom setup to bitbake-setup, allowing the use of master resources and local configuration management.

Objectives

As of November 7th 2025 the poky repository master branch is no longer being updated. How to deal with that how to use bitbake-setup and whinlatter on the phyBoard®-Pollux i.MX 8M Plus?

Prerequisites to use the RES build framework (RES)

Assuming you already have the Reliable Embedded Systems – Robert Berger e.U. Yocto Project®/OpenEmbedded build framework installed you are in a good position and can skip the chapter “Install a minimal Build framework”. I am describing this, since its the way I work, but that is not necessarily what you would like to do.

Install a minimal Build framework (RES)

Install docker

sudo apt install docker.io
sudo usermod -aG docker ${USER}
sudo reboot

Create a directory where you have plenty of space

mkdir -p ~/projects/resy-playground
cd ~/projects/resy-playground
sudo ln -sf ~/projects/resy-playground /workdir

You might need to fix some permissions.

Download manifests

mkdir -p /workdir/sources
pushd /workdir/sources
git clone https://github.com/RobertBerger/manifests.git
popd
cd /workdir
ln -sf sources/manifests/resy-poky-container.sh resy-poky-container.sh
chmod +x resy-poky-container.sh

On host machine

Download the BitBake repository

In order to use the bitbake-setup tool we need to get it. It’s part of the BitBake repository.

mkdir -p /workdir/sources/bitbake-new
cd /workdir/sources/bitbake-new
git clone https://github.com/openembedded/bitbake.git

Start docker build container

cd /workdir
./resy-poky-container.sh

In container

cd /workdir/sources/bitbake-new/bitbake

bitbake-setup init

./bin/bitbake-setup --setting default top-dir-prefix /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned init https://gitlab.com/meta-layers/meta-res-ampliphy-phyboard-pollux-imx8mp-3/-/raw/master/registry/configurations/yocto-ampliphy-master-2025-11-29-01-pinned.conf.json
Bitbake-setup is using /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds as top directory.

/workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds looks like a new top directory. If you would like to use a different directory, answer "n" below and either:
        1) Change the default bitbake-setup settings:
                bitbake-setup settings set default top-level-prefix <PATH>
                bitbake-setup settings set default top-level-name <NAME>
        2) Pass one or more options on the command line to change the top level directory in that invocation only:
                bitbake-setup --setting default top-dir-prefix <PATH> ...
                bitbake-setup --setting default top-dir-name <NAME> ...

A common site.conf file will be created, please check it is correct before running builds
    /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/site.conf

Proceed? (y/N): y
Reading configuration from network URI
    https://gitlab.com/meta-layers/meta-res-ampliphy-phyboard-pollux-imx8mp-3/-/raw/master/registry/configurations/yocto-ampliphy-master-2025-11-29-01-pinned.conf.json

Selecting the only available bitbake configuration yocto-ampliphy-pinned

Target machines:
1. machine/phyboard-pollux-imx8mp-3

Please select one of the above options by its number:
1
Distribution configuration variants:
1. distro/ampliphy
2. distro/ampliphy-rt

Please select one of the above options by its number:
1
Run 'bitbake-setup init --non-interactive https://gitlab.com/meta-layers/meta-res-ampliphy-phyboard-pollux-imx8mp-3/-/raw/master/registry/configurations/yocto-ampliphy-master-2025-11-29-01-pinned.conf.json yocto-ampliphy-pinned distro/ampliphy machine/phyboard-pollux-imx8mp-3' to select this configuration non-interactively.

Enter setup directory name: [yocto-ampliphy-pinned]
Initializing a setup directory in
    /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned
Continue? (y/N): y
Fetching layer/tool repositories into /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/layers
    bitbake
    openembedded-core
    meta-yocto
    yocto-docs
    meta-openembedded
    fsl-community
    meta-arm
    meta-rauc
    meta-virtualization
    meta-qt6
    meta-phytec
    meta-ampliphy
    meta-res-ampliphy-phyboard-pollux-imx8mp-3

Setting up bitbake configuration in
    /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/build

This bitbake configuration provides:
    Ampliphy - The Yocto Project/Phytec testing distribution: u-boot-master pinned, linux-yocto pinned

Usage instructions and additional information are in
     /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/build/README

To run builds, source the environment using
    . /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/build/init-build-env

Run 'bitbake-config-build enable-fragment <fragment-name>' to enable additional fragments or replace built-in ones (e.g. machine/<name> or distro/<name> to change MACHINE or DISTRO).

The bitbake configuration files (local.conf, bblayers.conf and more) can be found in
    /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/build/conf

Setup Build environment

source /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/build/init-build-env
Ampliphy - The Yocto Project/Phytec testing distribution: u-boot-master pinned, linux-yocto pinned

Check for configuration fragments

List fragments

bitbake-config-build list-fragments
NOTE: Starting bitbake server...
Available built-in fragments:
machine/...     Sets MACHINE = ...
distro/...      Sets DISTRO = ...

Enabled built-in fragments:
distro/ampliphy Sets DISTRO = "ampliphy"
machine/phyboard-pollux-imx8mp-3        Sets MACHINE = "phyboard-pollux-imx8mp-3"

Available fragments in core layer located in /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/layers/openembedded-core/meta:

Enabled fragments:
core/yocto/root-login-with-empty-password       Log in as root without password on serial console and over ssh (use with caution).

Unused fragments:
core/yocto/sstate-mirror-cdn    Use prebuilt sstate artifacts for standard Yocto build configurations.
core/yocto-autobuilder/autobuilder-resource-constraints Resource constraint variables used on the Yocto Projects autobuilder
core/yocto-autobuilder/autobuilder      Default variables used on the Yocto Projects autobuilder builds
core/yocto-autobuilder/multilib-mips64-n32      Enable a MIPS64 triarch multilib
core/yocto-autobuilder/multilib-x86-lib32       Enable an x86 lib32 multilib
core/yocto-autobuilder/multilib-x86-lib64       Enable an x86 lib64 multilib

Available fragments in meta-res-ampliphy-phyboard-pollux-imx8mp-3 layer located in /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/layers/meta-res-ampliphy-phyboard-pollux-imx8mp-3:

Enabled fragments:
meta-res-ampliphy-phyboard-pollux-imx8mp-3/accept-fsl-eula      Accept Freescale EULA.
meta-res-ampliphy-phyboard-pollux-imx8mp-3/enable-buildhistory  Enable buildhistory.
meta-res-ampliphy-phyboard-pollux-imx8mp-3/enable-git-shallow   Enabled mirror tarballs of shallow git repositories.
meta-res-ampliphy-phyboard-pollux-imx8mp-3/generate-mirror-tarballs     Generate mirror tarballs.
meta-res-ampliphy-phyboard-pollux-imx8mp-3/package-ipk  use ipk.
meta-res-ampliphy-phyboard-pollux-imx8mp-3/preferred-provider-linux-yocto       PREFERRED_PROVIDER virtual/kernel = linux-yocto
meta-res-ampliphy-phyboard-pollux-imx8mp-3/preferred-provider-u-boot-master-pinned      PREFERRED_PROVIDER virtual/bootloader = u-boot-master, SRCREV is pinned

Unused fragments:
meta-res-ampliphy-phyboard-pollux-imx8mp-3/enable-cve-check     Enable the cve-check class.
meta-res-ampliphy-phyboard-pollux-imx8mp-3/enable-daniel-turull-kernel-cve      Prepare for Daniel Turull kernel CVE.
meta-res-ampliphy-phyboard-pollux-imx8mp-3/preferred-provider-linux-yocto-dev-pinned    PREFERRED_PROVIDER virtual/kernel = linux-yocto-dev, SRCREV pinned
meta-res-ampliphy-phyboard-pollux-imx8mp-3/preferred-provider-linux-yocto-dev   PREFERRED_PROVIDER virtual/kernel = linux-yocto-dev
meta-res-ampliphy-phyboard-pollux-imx8mp-3/preferred-provider-linux-yocto-pinned        PREFERRED_PROVIDER virtual/kernel = linux-yocto
meta-res-ampliphy-phyboard-pollux-imx8mp-3/preferred-provider-u-boot-master     PREFERRED_PROVIDER virtual/bootloader = u-boot-master
meta-res-ampliphy-phyboard-pollux-imx8mp-3/preferred-provider-u-boot-phytec     PREFERRED_PROVIDER virtual/bootloader = u-boot-phytec

Create a site.conf (optional – RES specific)

cp ${BUILDDIR}/../layers/meta-res-ampliphy-phyboard-pollux-imx8mp-3/extra-conf/site.conf ${BUILDDIR}/../../site.conf

cat ${BUILDDIR}/../../site.conf
# This file is intended for build host-specific bitbake settings

PREMIRRORS += " \
git://git.denx.de/u-boot.git git://192.168.42.182:8939/robert.berger/u-boot.git;protocol=http \n \
git://git.kernel.org/pub/scm/linux/kernel/git/stable/linux-stable.git git://192.168.42.182:8939/robert.berger/linux-stable.git;protocol=http \n \
git://git.yoctoproject.org/linux-yocto.git git://192.168.42.182:8939/robert.berger/linux-yocto.git;protocol=http \n \
git://git.yoctoproject.org/linux-yocto-dev.git git://192.168.42.182:8939/robert.berger/linux-yocto-dev.git;protocol=http \n \
git://git.yoctoproject.org/yocto-kernel-cache git://192.168.42.182:8939/robert.berger/yocto-kernel-cache.git;protocol=http \n \
git://github.com/raspberrypi/linux.git git://192.168.42.182:8939/robert.berger/raspberrypi-linux.git;protocol=http \n \
"
# --> shared between local builds on the same machine
DL_DIR = "/workdir/downloads_whinlatter"
SSTATE_DIR = "/workdir/sstate_whinlatter/"
# <-- shared between local builds on the same machine

Patch Phytec layer(s)

In order to be able to use the standard Yocto kernel as opposed to the -dev Yocto kernel we’ll need a small patch.

pushd ${BUILDDIR}/../layers/meta-res-ampliphy-phyboard-pollux-imx8mp-3/patches/

./patch.sh
BUILDDIR: /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/build
=================================================>
/workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/layers /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/layers/meta-res-ampliphy-phyboard-pollux-imx8mp-3/patches
/workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/layers/meta-phytec /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/layers /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/layers/meta-res-ampliphy-phyboard-pollux-imx8mp-3/patches
On branch master
Your branch is behind 'origin/master' by 41 commits, and can be fast-forwarded.
  (use "git pull" to update your local branch)

Changes not staged for commit:
  (use "git add <file>..." to update what will be committed)
  (use "git restore <file>..." to discard changes in working directory)
        modified:   recipes-kernel/linux/linux-yocto_%.bbappend

no changes added to commit (use "git add" and/or "git commit -a")
/workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/layers /workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/layers/meta-res-ampliphy-phyboard-pollux-imx8mp-3/patches
/workdir/build/yocto-ampliphy-master-2025-11-29-01-pinned/bitbake-builds/yocto-ampliphy-pinned/layers/meta-res-ampliphy-phyboard-pollux-imx8mp-3/patches
<=================================================
popd

Build phytec-headless-image

bitbake phytec-headless-image
Loading cache: 100% |##########################################################################################################################################################| Time: 0:00:00
Loaded 0 entries from dependency cache.
Parsing recipes: 100% |########################################################################################################################################################| Time: 0:01:06
Parsing of 3748 .bb files complete (0 cached, 3748 parsed). 6163 targets, 804 skipped, 4 masked, 0 errors.
NOTE: Resolving any missing task queue dependencies

Build Configuration:
BB_VERSION           = "2.16.0"
BUILD_SYS            = "x86_64-linux"
NATIVELSBSTRING      = "ubuntu-22.04"
TARGET_SYS           = "aarch64-phytec-linux"
MACHINE              = "phyboard-pollux-imx8mp-3"
DISTRO               = "ampliphy"
DISTRO_VERSION       = "BSP-Yocto-Ampliphy-i.MX8MP-master-devel"
TUNE_FEATURES        = "aarch64"
TARGET_FPU           = ""
meta                 = "master:ac7327583aef83fd400190506f3147623de38b68"
meta-yocto-bsp
meta-poky            = "master:b3b659263566c4d2f2813190e72d93f8598a4c47"
meta-oe
meta-networking
meta-python
meta-multimedia
meta-filesystems
meta-perl            = "master:91389e4d5aff2180fb947746c058c520ff3ea042"
meta-freescale       = "master:1f1dd28237aeaf07604a7f5d3c09819339c7be94"
meta-arm
meta-arm-toolchain   = "master:aff67cb5d748aafcba1ee589a758d51191f061c2"
meta-rauc            = "master:11266f6fa350133704da2f1d7380ab4241cd8fea"
meta-virtualization  = "master:c2185cd5ef225c6606341745ad9ffb02efe364d9"
meta-qt6             = "dev:080b412a617e18c28182763bae625eb6fd17ea97"
meta-phytec          = "master:b5dbcb129fdd0d0104ce28d14a088bfcb68e91ff"
meta-ampliphy        = "master:5c20a0f50a4d2d29a73168de7dd45cfe98e8e50d"
meta-res-ampliphy-phyboard-pollux-imx8mp-3 = "master:aace0593b6dfcc07b9d7676525850c440823f0cf"

Sstate summary: Wanted 3932 Local 3928 Mirrors 0 Missed 4 Current 0 (99% match, 0% complete)###################################################################                | ETA:  0:00:00
Initialising tasks: 100% |#####################################################################################################################################################| Time: 0:00:05
NOTE: Executing Tasks
NOTE: Tasks Summary: Attempted 7692 tasks of which 7676 didn't need to be rerun and all succeeded.
NOTE: Writing buildhistory
NOTE: Writing buildhistory took: 4 seconds

Now we should have a “phytec-headless-image”. We will try to run it on the phyBoard®-Pollux i.MX 8M Plus.

Check for AUTOREV

cd ${BUILDDIR}
buildhistory-collect-srcrevs

Nothing is returned, which is good, since it means we have no floating versions. AUTOREV is not used.

On host machine (RES)

Flash the SD card for the board

I use some custom script for that but it boils down to using the bmap-tool together with wic and wic.bmap files.

sudo bmaptool copy phytec-headless-image-phyboard-pollux-imx8mp-3.rootfs-20251204130851.wic.xz /dev/sdb
bmaptool: info: discovered bmap file 'phytec-headless-image-phyboard-pollux-imx8mp-3.rootfs-20251204130851.wic.bmap'                                                                          
bmaptool: info: block map format version 2.0                                                   
bmaptool: info: 302009 blocks of size 4096 (1.2 GiB), mapped 163199 blocks (637.5 MiB or 54.0%)                                                                                               
bmaptool: info: copying image 'phytec-headless-image-phyboard-pollux-imx8mp-3.rootfs-20251204130851.wic.xz' to block device '/dev/sdb' using bmap file 'phytec-headless-image-phyboard-pollux-
imx8mp-3.rootfs-20251204130851.wic.bmap'                                                       
bmaptool: info: 100% copied                                                                    
bmaptool: info: synchronizing '/dev/sdb'                                                       
bmaptool: info: copying time: 45.7s, copying speed 13.9 MiB/sec

Insert the SD card in the board, connect a serial console and power up your board.

Power Up

Here we see a bootlog

U-Boot SPL 2026.01-rc2 (Nov 22 2025 - 14:49:09 +0000)
phytec_eeprom_data_init: EEPROM is not flashed. Prototype?
phytec_eeprom_data_setup_fallback: init failed. Trying fall back address 0x59
SOM: PCM-070-0F3243I.A3
PCB Rev.: 2
WDT:   Started watchdog@30280000 with servicing every 1000ms (60s timeout)
SEC0:  RNG instantiated
Trying to boot from BOOTROM
Boot Stage: Primary boot
image offset 0x8000, pagesize 0x200, ivt offset 0x0
NOTICE:  Do not release JR0 to NS as it can be used by HAB
NOTICE:  BL31: v2.13.0(release):v2.13.0-dirty
NOTICE:  BL31: Built : 10:24:05, May 22 2025


U-Boot 2026.01-rc2 (Nov 22 2025 - 14:49:09 +0000)

CPU:   NXP i.MX8MP[8] Rev1.1 A53 at 1200 MHz
CPU:   Industrial temperature grade (-40C to 105C) at 23C
Model: PHYTEC phyBOARD-Pollux i.MX8MP
DRAM:  2 GiB
phytec_eeprom_data_init: EEPROM is not flashed. Prototype?
phytec_eeprom_data_setup_fallback: init failed. Trying fall back address 0x59
Core:  250 devices, 33 uclasses, devicetree: separate
WDT:   Started watchdog@30280000 with servicing every 1000ms (60s timeout)
MMC:   FSL_SDHC: 1, FSL_SDHC: 2
Loading Environment from MMC... *** Warning - bad CRC, using default environment

Reading from MMC(1)... In:    serial@30860000
Out:   serial@30860000
Err:   serial@30860000
SEC0:  RNG instantiated
Net:   eth0: ethernet@30be0000
Hit any key to stop autoboot: 0
Scanning for bootflows in all bootdevs
Seq  Method       State   Uclass    Part  Name                      Filename
---  -----------  ------  --------  ----  ------------------------  ----------------
Scanning bootdev 'mmc@30b60000.bootdev':
Scanning bootdev 'mmc@30b50000.bootdev':
  0  script       ready   mmc          1  mmc@30b50000.bootdev.part /boot.scr.uimg
** Booting bootflow 'mmc@30b50000.bootdev.part_1' with script
14854716 bytes read in 158 ms (89.7 MiB/s)
Working FDT set to 40480000
## Loading kernel (any) from FIT Image at 40480000 ...
   Using 'conf-imx8mp-phyboard-pollux-rdk.dtb' configuration
   Verifying Hash Integrity ... OK
   Trying 'kernel-1' kernel subimage
     Description:  Linux kernel
     Type:         Kernel Image
     Compression:  gzip compressed
     Data Start:   0x40480130
     Data Size:    14782147 Bytes = 14.1 MiB
     Architecture: AArch64
     OS:           Linux
     Load Address: 0x5a080000
     Entry Point:  0x5a080000
     Hash algo:    sha256
     Hash value:   fed6a485ea7ed3e46fb88b17a106a9f8bcf7facd2a814fe3f45b374ee75a11c9
   Verifying Hash Integrity ... sha256+ OK
## Loading fdt (any) from FIT Image at 40480000 ...
   Using 'conf-imx8mp-phyboard-pollux-rdk.dtb' configuration
   Verifying Hash Integrity ... OK
   Trying 'fdt-imx8mp-phyboard-pollux-rdk.dtb' fdt subimage
     Description:  Flattened Device Tree blob
     Type:         Flat Device Tree
     Compression:  uncompressed
     Data Start:   0x41299114
     Data Size:    71208 Bytes = 69.5 KiB
     Architecture: AArch64
     Load Address: 0x48000000
     Hash algo:    sha256
     Hash value:   794fdd4ea99dd47fb9c243f2ed5654dc779de21d71b8ce091c0c198487604e18
   Verifying Hash Integrity ... sha256+ OK
   Loading fdt from 0x41299114 to 0x48000000
   Booting using the fdt blob at 0x48000000
Working FDT set to 48000000
   Uncompressing Kernel Image to 5a080000
Moving Image from 0x5a080000 to 0x5a200000, end=0x5ca30000
   Loading Device Tree to 000000007ae97000, end 000000007aeab627 ... OK
Working FDT set to 7ae97000
Device nor0 not found!

Starting kernel ...

[    0.000000] Booting Linux on physical CPU 0x0000000000 [0x410fd034]
[    0.000000] Linux version 6.16.11-yocto-standard-g42ddd61a7bce (oe-user@oe-host) (aarch64-phytec-linux-gcc (GCC) 15.2.0, GNU ld (GNU Binutils) 2.45.0.20250908) #1 SMP PREEMPT Mon Oct  6 13:50:41 UTC 2025
[    0.000000] KASLR enabled
[    0.000000] Machine model: PHYTEC phyBOARD-Pollux i.MX8MP
[    0.000000] efi: UEFI not found.
[    0.000000] earlycon: ec_imx6q0 at MMIO 0x0000000030860000 (options '')
[    0.000000] printk: legacy bootconsole [ec_imx6q0] enabled
[    0.000000] OF: reserved mem: 0x000000007fc00000..0x000000007fffffff (4096 KiB) nomap non-reusable optee_shm@7fc00000
[    0.000000] OF: reserved mem: 0x000000007e000000..0x000000007fbfffff (28672 KiB) nomap non-reusable optee_core@7e000000
[    0.000000] NUMA: Faking a node at [mem 0x0000000040000000-0x00000000bfffffff]
[    0.000000] NODE_DATA(0) allocated [mem 0xbfbb7240-0xbfbb98bf]
[    0.000000] Zone ranges:
[    0.000000]   DMA      [mem 0x0000000040000000-0x00000000bfffffff]
[    0.000000]   DMA32    empty
[    0.000000]   Normal   empty
[    0.000000] Movable zone start for each node
[    0.000000] Early memory node ranges
[    0.000000]   node   0: [mem 0x0000000040000000-0x000000007dffffff]
[    0.000000]   node   0: [mem 0x0000000080000000-0x00000000bfffffff]
[    0.000000] Initmem setup node 0 [mem 0x0000000040000000-0x00000000bfffffff]
[    0.000000] On node 0, zone DMA: 8192 pages in unavailable ranges
[    0.000000] cma: Reserved 32 MiB at 0x00000000bba00000
[    0.000000] psci: probing for conduit method from DT.
[    0.000000] psci: PSCIv1.1 detected in firmware.
[    0.000000] psci: Using standard PSCI v0.2 function IDs
[    0.000000] psci: Trusted OS migration not required
[    0.000000] psci: SMC Calling Convention v1.5
[    0.000000] percpu: Embedded 25 pages/cpu s62616 r8192 d31592 u102400
[    0.000000] Detected VIPT I-cache on CPU0
[    0.000000] CPU features: detected: GIC system register CPU interface
[    0.000000] CPU features: kernel page table isolation forced ON by KASLR
[    0.000000] CPU features: detected: Kernel page table isolation (KPTI)
[    0.000000] CPU features: detected: ARM erratum 845719
[    0.000000] alternatives: applying boot alternatives
[    0.000000] Kernel command line: console=ttymxc0,115200 earlycon= root=/dev/mmcblk1p2  rootwait rw
[    0.000000] printk: log buffer data + meta data: 131072 + 458752 = 589824 bytes
[    0.000000] Dentry cache hash table entries: 262144 (order: 9, 2097152 bytes, linear)
[    0.000000] Inode-cache hash table entries: 131072 (order: 8, 1048576 bytes, linear)
[    0.000000] software IO TLB: SWIOTLB bounce buffer size adjusted to 1MB
[    0.000000] software IO TLB: area num 4.
[    0.000000] software IO TLB: mapped [mem 0x00000000bb600000-0x00000000bb800000] (2MB)
[    0.000000] Fallback order for Node 0: 0
[    0.000000] Built 1 zonelists, mobility grouping on.  Total pages: 516096
[    0.000000] Policy zone: DMA
[    0.000000] mem auto-init: stack:all(zero), heap alloc:off, heap free:off
[    0.000000] SLUB: HWalign=64, Order=0-3, MinObjects=0, CPUs=4, Nodes=1
[    0.000000] rcu: Preemptible hierarchical RCU implementation.
[    0.000000] rcu:     RCU event tracing is enabled.
[    0.000000] rcu:     RCU restricting CPUs from NR_CPUS=512 to nr_cpu_ids=4.
[    0.000000]  Trampoline variant of Tasks RCU enabled.
[    0.000000]  Tracing variant of Tasks RCU enabled.
[    0.000000] rcu: RCU calculated value of scheduler-enlistment delay is 25 jiffies.
[    0.000000] rcu: Adjusting geometry for rcu_fanout_leaf=16, nr_cpu_ids=4
[    0.000000] RCU Tasks: Setting shift to 2 and lim to 1 rcu_task_cb_adjust=1 rcu_task_cpu_ids=4.
[    0.000000] RCU Tasks Trace: Setting shift to 2 and lim to 1 rcu_task_cb_adjust=1 rcu_task_cpu_ids=4.
[    0.000000] NR_IRQS: 64, nr_irqs: 64, preallocated irqs: 0
[    0.000000] GICv3: GIC: Using split EOI/Deactivate mode
[    0.000000] GICv3: 160 SPIs implemented
[    0.000000] GICv3: 0 Extended SPIs implemented
[    0.000000] Root IRQ handler: gic_handle_irq
[    0.000000] GICv3: GICv3 features: 16 PPIs
[    0.000000] GICv3: GICD_CTRL.DS=0, SCR_EL3.FIQ=1
[    0.000000] GICv3: CPU0: found redistributor 0 region 0:0x0000000038880000
[    0.000000] ITS: No ITS available, not enabling LPIs
[    0.000000] rcu: srcu_init: Setting srcu_struct sizes based on contention.
[    0.000000] arch_timer: cp15 timer(s) running at 8.00MHz (phys).
[    0.000000] clocksource: arch_sys_counter: mask: 0xffffffffffffff max_cycles: 0x1d854df40, max_idle_ns: 440795202120 ns
[    0.000000] sched_clock: 56 bits at 8MHz, resolution 125ns, wraps every 2199023255500ns
[    0.010080] Console: colour dummy device 80x25
[    0.012579] Calibrating delay loop (skipped), value calculated using timer frequency.. 16.00 BogoMIPS (lpj=32000)
[    0.022845] pid_max: default: 32768 minimum: 301
[    0.027546] LSM: initializing lsm=capability
[    0.031871] Mount-cache hash table entries: 4096 (order: 3, 32768 bytes, linear)
[    0.039210] Mountpoint-cache hash table entries: 4096 (order: 3, 32768 bytes, linear)
[    0.049036] rcu: Hierarchical SRCU implementation.
[    0.051924] rcu:     Max phase no-delay instances is 1000.
[    0.057355] Timer migration: 1 hierarchy levels; 8 children per group; 1 crossnode level
[    0.068830] EFI services will not be available.
[    0.070765] smp: Bringing up secondary CPUs ...
[    0.075538] Detected VIPT I-cache on CPU1
[    0.075603] GICv3: CPU1: found redistributor 1 region 0:0x00000000388a0000
[    0.075639] CPU1: Booted secondary processor 0x0000000001 [0x410fd034]
[    0.076220] Detected VIPT I-cache on CPU2
[    0.076269] GICv3: CPU2: found redistributor 2 region 0:0x00000000388c0000
[    0.076291] CPU2: Booted secondary processor 0x0000000002 [0x410fd034]
[    0.076813] Detected VIPT I-cache on CPU3
[    0.076862] GICv3: CPU3: found redistributor 3 region 0:0x00000000388e0000
[    0.076883] CPU3: Booted secondary processor 0x0000000003 [0x410fd034]
[    0.076992] smp: Brought up 1 node, 4 CPUs
[    0.131695] SMP: Total of 4 processors activated.
[    0.136409] CPU: All CPU(s) started at EL2
[    0.140564] CPU features: detected: 32-bit EL0 Support
[    0.145688] CPU features: detected: 32-bit EL1 Support
[    0.150861] CPU features: detected: CRC32 instructions
[    0.156017] CPU features: detected: PMUv3
[    0.160075] alternatives: applying system-wide alternatives
[    0.166941] Memory: 1943236K/2064384K available (18624K kernel code, 5354K rwdata, 12868K rodata, 3264K init, 755K bss, 83944K reserved, 32768K cma-reserved)
[    0.180420] devtmpfs: initialized
[    0.194192] clocksource: jiffies: mask: 0xffffffff max_cycles: 0xffffffff, max_idle_ns: 7645041785100000 ns
[    0.201175] posixtimers hash table entries: 2048 (order: 3, 32768 bytes, linear)
[    0.208660] futex hash table entries: 1024 (65536 bytes on 1 NUMA nodes, total 64 KiB, linear).
[    0.217994] 2G module region forced by RANDOMIZE_MODULE_REGION_FULL
[    0.223672] 0 pages in range for non-PLT usage
[    0.223677] 514000 pages in range for PLT usage
[    0.228347] pinctrl core: initialized pinctrl subsystem
[    0.241368] DMI not present or invalid.
[    0.244992] NET: Registered PF_NETLINK/PF_ROUTE protocol family
[    0.249729] DMA: preallocated 256 KiB GFP_KERNEL pool for atomic allocations
[    0.256213] DMA: preallocated 256 KiB GFP_KERNEL|GFP_DMA pool for atomic allocations
[    0.264289] DMA: preallocated 256 KiB GFP_KERNEL|GFP_DMA32 pool for atomic allocations
[    0.273008] thermal_sys: Registered thermal governor 'step_wise'
[    0.273019] thermal_sys: Registered thermal governor 'power_allocator'
[    0.277287] cpuidle: using governor menu
[    0.287929] hw-breakpoint: found 6 breakpoint and 4 watchpoint registers.
[    0.294596] ASID allocator initialised with 32768 entries
[    0.302929] Serial: AMBA PL011 UART driver
[    0.314142] /soc@0: Fixed dependency cycle(s) with /soc@0/bus@30000000/efuse@30350000/unique-id@8
[    0.320289] /soc@0/etm@28440000: Fixed dependency cycle(s) with /funnel
[    0.327002] /soc@0/etm@28540000: Fixed dependency cycle(s) with /funnel
[    0.333580] /soc@0/etm@28640000: Fixed dependency cycle(s) with /funnel
[    0.340227] /soc@0/etm@28740000: Fixed dependency cycle(s) with /funnel
[    0.346853] /soc@0/funnel@28c03000: Fixed dependency cycle(s) with /soc@0/etf@28c04000
[    0.354817] /soc@0/funnel@28c03000: Fixed dependency cycle(s) with /funnel
[    0.361728] /soc@0/etf@28c04000: Fixed dependency cycle(s) with /soc@0/etr@28c06000
[    0.369436] /soc@0/etf@28c04000: Fixed dependency cycle(s) with /soc@0/funnel@28c03000
[    0.377419] /soc@0/etr@28c06000: Fixed dependency cycle(s) with /soc@0/etf@28c04000
[    0.385855] /soc@0/bus@32c00000/display-controller@32e90000: Fixed dependency cycle(s) with /soc@0/bus@32c00000/blk-ctrl@32ec0000/bridge@5c
[    0.397782] /soc@0/bus@32c00000/blk-ctrl@32ec0000/bridge@5c: Fixed dependency cycle(s) with /soc@0/bus@32c00000/display-controller@32e90000
[    0.410714] /soc@0/interrupt-controller@38800000: Fixed dependency cycle(s) with /soc@0/interrupt-controller@38800000
[    0.421740] /funnel: Fixed dependency cycle(s) with /soc@0/etm@28440000
[    0.427702] /soc@0/etm@28440000: Fixed dependency cycle(s) with /funnel
[    0.434393] /funnel: Fixed dependency cycle(s) with /soc@0/etm@28540000
[    0.440991] /soc@0/etm@28540000: Fixed dependency cycle(s) with /funnel
[    0.447685] /funnel: Fixed dependency cycle(s) with /soc@0/etm@28640000
[    0.454283] /soc@0/etm@28640000: Fixed dependency cycle(s) with /funnel
[    0.460990] /funnel: Fixed dependency cycle(s) with /soc@0/etm@28740000
[    0.467582] /soc@0/etm@28740000: Fixed dependency cycle(s) with /funnel
[    0.474308] /funnel: Fixed dependency cycle(s) with /soc@0/funnel@28c03000
[    0.481129] /soc@0/funnel@28c03000: Fixed dependency cycle(s) with /soc@0/etf@28c04000
[    0.489047] /soc@0/funnel@28c03000: Fixed dependency cycle(s) with /funnel
[    0.496106] /soc@0/funnel@28c03000: Fixed dependency cycle(s) with /soc@0/etf@28c04000
[    0.503959] /soc@0/etf@28c04000: Fixed dependency cycle(s) with /soc@0/etr@28c06000
[    0.511632] /soc@0/etf@28c04000: Fixed dependency cycle(s) with /soc@0/funnel@28c03000
[    0.519702] /soc@0/etf@28c04000: Fixed dependency cycle(s) with /soc@0/etr@28c06000
[    0.527351] /soc@0/etr@28c06000: Fixed dependency cycle(s) with /soc@0/etf@28c04000
[    0.540801] imx8mp-pinctrl 30330000.pinctrl: initialized IMX pinctrl driver
[    0.545849] /soc@0/bus@30000000/efuse@30350000: Fixed dependency cycle(s) with /soc@0/bus@30000000/clock-controller@30380000
[    0.558658] /soc@0/bus@30000000/efuse@30350000: Fixed dependency cycle(s) with /soc@0/bus@30000000/clock-controller@30380000
[    0.568519] /soc@0/bus@30000000/clock-controller@30380000: Fixed dependency cycle(s) with /soc@0/interrupt-controller@38800000
[    0.594428] /soc@0/bus@32c00000/display-controller@32e90000: Fixed dependency cycle(s) with /soc@0/bus@32c00000/blk-ctrl@32ec0000/bridge@5c
[    0.604346] /soc@0/bus@32c00000/blk-ctrl@32ec0000/bridge@5c: Fixed dependency cycle(s) with /soc@0/bus@32c00000/display-controller@32e90000
[    0.617760] /soc@0/bus@32c00000/display-controller@32e90000: Fixed dependency cycle(s) with /soc@0/bus@32c00000/blk-ctrl@32ec0000/bridge@5c
[    0.630120] /soc@0/bus@32c00000/blk-ctrl@32ec0000/bridge@5c: Fixed dependency cycle(s) with /soc@0/bus@32c00000/display-controller@32e90000
[    0.651701] /soc@0/bus@32c00000/blk-ctrl@32ec0000/bridge@5c: Fixed dependency cycle(s) with /panel-lvds
[    0.658421] /panel-lvds: Fixed dependency cycle(s) with /soc@0/bus@32c00000/blk-ctrl@32ec0000/bridge@5c
[    0.672185] HugeTLB: allocation took 0ms with hugepage_allocation_threads=1
[    0.676346] HugeTLB: allocation took 0ms with hugepage_allocation_threads=1
[    0.683342] HugeTLB: registered 1.00 GiB page size, pre-allocated 0 pages
[    0.690160] HugeTLB: 0 KiB vmemmap can be freed for a 1.00 GiB page
[    0.696461] HugeTLB: registered 32.0 MiB page size, pre-allocated 0 pages
[    0.703284] HugeTLB: 0 KiB vmemmap can be freed for a 32.0 MiB page
[    0.709584] HugeTLB: registered 2.00 MiB page size, pre-allocated 0 pages
[    0.716408] HugeTLB: 0 KiB vmemmap can be freed for a 2.00 MiB page
[    0.722712] HugeTLB: registered 64.0 KiB page size, pre-allocated 0 pages
[    0.729532] HugeTLB: 0 KiB vmemmap can be freed for a 64.0 KiB page
[    0.738181] ACPI: Interpreter disabled.
[    0.744238] iommu: Default domain type: Translated
[    0.746195] iommu: DMA domain TLB invalidation policy: strict mode
[    0.752763] SCSI subsystem initialized
[    0.756599] usbcore: registered new interface driver usbfs
[    0.761727] usbcore: registered new interface driver hub
[    0.767051] usbcore: registered new device driver usb
[    0.773858] pps_core: LinuxPPS API ver. 1 registered
[    0.777092] pps_core: Software ver. 5.3.6 - Copyright 2005-2007 Rodolfo Giometti <giometti@linux.it>
[    0.786286] PTP clock support registered
[    0.790360] EDAC MC: Ver: 3.0.0
[    0.793931] scmi_core: SCMI protocol bus registered
[    0.799699] FPGA manager framework
[    0.801763] Advanced Linux Sound Architecture Driver Initialized.
[    0.808877] vgaarb: loaded
[    0.810965] clocksource: Switched to clocksource arch_sys_counter
[    0.816882] VFS: Disk quotas dquot_6.6.0
[    0.820595] VFS: Dquot-cache hash table entries: 512 (order 0, 4096 bytes)
[    0.827711] pnp: PnP ACPI: disabled
[    0.838272] NET: Registered PF_INET protocol family
[    0.840473] IP idents hash table entries: 32768 (order: 6, 262144 bytes, linear)
[    0.849288] tcp_listen_portaddr_hash hash table entries: 1024 (order: 2, 16384 bytes, linear)
[    0.856391] Table-perturb hash table entries: 65536 (order: 6, 262144 bytes, linear)
[    0.864132] TCP established hash table entries: 16384 (order: 5, 131072 bytes, linear)
[    0.872188] TCP bind hash table entries: 16384 (order: 7, 524288 bytes, linear)
[    0.879877] TCP: Hash tables configured (established 16384 bind 16384)
[    0.886090] UDP hash table entries: 1024 (order: 4, 65536 bytes, linear)
[    0.892806] UDP-Lite hash table entries: 1024 (order: 4, 65536 bytes, linear)
[    0.900099] NET: Registered PF_UNIX/PF_LOCAL protocol family
[    0.906026] RPC: Registered named UNIX socket transport module.
[    0.911555] RPC: Registered udp transport module.
[    0.916271] RPC: Registered tcp transport module.
[    0.920996] RPC: Registered tcp-with-tls transport module.
[    0.926509] RPC: Registered tcp NFSv4.1 backchannel transport module.
[    0.932991] PCI: CLS 0 bytes, default 64
[    0.940864] kvm [1]: nv: 566 coarse grained trap handlers
[    0.943911] kvm [1]: IPA Size Limit: 40 bits
[    0.951435] kvm [1]: GICv3: no GICV resource entry
[    0.953380] kvm [1]: disabling GICv2 emulation
[    0.957868] kvm [1]: GIC system register CPU interface enabled
[    0.963734] kvm [1]: vgic interrupt IRQ9
[    0.967673] kvm [1]: Hyp nVHE mode initialized successfully
[    0.974612] Initialise system trusted keyrings
[    0.977938] workingset: timestamp_bits=42 max_order=19 bucket_order=0
[    0.984469] squashfs: version 4.0 (2009/01/31) Phillip Lougher
[    0.990271] NFS: Registering the id_resolver key type
[    0.995153] Key type id_resolver registered
[    0.999324] Key type id_legacy registered
[    1.003364] nfs4filelayout_init: NFSv4 File Layout Driver Registering...
[    1.010089] nfs4flexfilelayout_init: NFSv4 Flexfile Layout Driver Registering...
[    1.017706] 9p: Installing v9fs 9p2000 file system support
[    1.077918] Key type asymmetric registered
[    1.079180] Asymmetric key parser 'x509' registered
[    1.084115] Block layer SCSI generic (bsg) driver version 0.4 loaded (major 245)
[    1.091511] io scheduler mq-deadline registered
[    1.096060] io scheduler kyber registered
[    1.100114] io scheduler bfq registered
[    1.122071] ledtrig-cpu: registered to indicate activity on CPUs
[    1.162239] SoC: i.MX8MP revision 1.1
[    1.212546] Serial: 8250/16550 driver, 4 ports, IRQ sharing enabled
[    1.221598] 30860000.serial: ttymxc0 at MMIO 0x30860000 (irq = 15, base_baud = 1500000) is a IMX
[    1.227657] printk: console [ttymxc0] enabled
[    1.227657] printk: console [ttymxc0] enabled
[    1.236297] printk: legacy bootconsole [ec_imx6q0] disabled
[    1.236297] printk: legacy bootconsole [ec_imx6q0] disabled
[    1.252060] 30890000.serial: ttymxc1 at MMIO 0x30890000 (irq = 16, base_baud = 5000000) is a IMX
[    1.253192] msm_serial: driver initialized
[    1.253878] SuperH (H)SCI(F) driver initialized
[    1.254279] STM32 USART driver initialized
[    1.265826] loop: module loaded
[    1.267640] megasas: 07.734.00.00-rc1
[    1.273903] spi-nor spi0.0: supply vcc not found, using dummy regulator
[    1.286648] thunder_xcv, ver 1.0
[    1.286694] thunder_bgx, ver 1.0
[    1.286735] nicpf, ver 1.0
[    1.289262] hns3: Hisilicon Ethernet Network Driver for Hip08 Family - version
[    1.289269] hns3: Copyright (c) 2017 Huawei Corporation.
[    1.289322] hclge is initializing
[    1.289356] e1000: Intel(R) PRO/1000 Network Driver
[    1.289359] e1000: Copyright (c) 1999-2006 Intel Corporation.
[    1.289401] e1000e: Intel(R) PRO/1000 Network Driver
[    1.289403] e1000e: Copyright(c) 1999 - 2015 Intel Corporation.
[    1.289441] igb: Intel(R) Gigabit Ethernet Network Driver
[    1.289444] igb: Copyright (c) 2007-2014 Intel Corporation.
[    1.289487] igbvf: Intel(R) Gigabit Virtual Function Network Driver
[    1.289491] igbvf: Copyright (c) 2009 - 2012 Intel Corporation.
[    1.290097] sky2: driver version 1.30
[    1.292754] VFIO - User Level meta-driver version: 0.3
[    1.298886] usbcore: registered new interface driver usb-storage
[    1.304973] i2c_dev: i2c /dev entries driver
[    1.323838] sdhci: Secure Digital Host Controller Interface driver
[    1.323848] sdhci: Copyright(c) Pierre Ossman
[    1.325509] Synopsys Designware Multimedia Card Interface Driver
[    1.328010] sdhci-pltfm: SDHCI platform and OF driver helper
[    1.333906] SMCCC: SOC_ID: ARCH_SOC_ID not implemented, skipping ....
[    1.335808] usbcore: registered new interface driver usbhid
[    1.335816] usbhid: USB HID core driver
[    1.345103] hw perfevents: enabled with armv8_cortex_a53 PMU driver, 7 (0,8000003f) counters available
[    1.348155] nvmem imx-ocotp0: cell mac-address raw len 6 unaligned to nvmem word size 4
[    1.348173] nvmem imx-ocotp0: cell mac-address raw len 6 unaligned to nvmem word size 4
[    1.348479] /soc@0: Fixed dependency cycle(s) with /soc@0/bus@30000000/efuse@30350000
[    1.351775] optee: probing for conduit method.
[    1.351803] optee: revision 4.7 (86846f4fdf14f25b)
[    1.352138] optee: dynamic shared memory is enabled
[    1.353208] random: crng init done
[    1.353228] optee: initialized driver
[    1.359031] mmc2: SDHCI controller on 30b60000.mmc [30b60000.mmc] using ADMA
[    1.359426] NET: Registered PF_PACKET protocol family
[    1.359472] 8021q: 802.1Q VLAN Support v1.8
[    1.359518] 9pnet: Installing 9P2000 support
[    1.359571] Key type dns_resolver registered
[    1.359743] NET: Registered PF_VSOCK protocol family
[    1.372519] registered taskstats version 1
[    1.372648] Loading compiled-in X.509 certificates
[    1.386908] Demotion targets for Node 0: null
[    1.424638] mmc2: new HS400 Enhanced strobe MMC card at address 0001
[    1.424765] i2c i2c-0: using pinctrl states for GPIO recovery
[    1.424825] i2c i2c-0: using generic GPIOs for recovery
[    1.425243] mmcblk2: mmc2:0001 DG4008 7.28 GiB
[    1.425795] i2c i2c-0: IMX I2C adapter registered
[    1.426998] mmcblk2boot0: mmc2:0001 DG4008 4.00 MiB
[    1.427354] i2c i2c-1: using pinctrl states for GPIO recovery
[    1.427422] i2c i2c-1: using generic GPIOs for recovery
[    1.427917] i2c i2c-1: IMX I2C adapter registered
[    1.428726] mmcblk2boot1: mmc2:0001 DG4008 4.00 MiB
[    1.430519] mmcblk2rpmb: mmc2:0001 DG4008 4.00 MiB, chardev (234:0)
[    1.436014] nxp-pca9450 0-0025: pca9450bc probed.
[    1.451069] /panel-lvds: Fixed dependency cycle(s) with /soc@0/bus@32c00000/blk-ctrl@32ec0000/bridge@5c
[    1.451164] /soc@0/bus@32c00000/display-controller@32e90000: Fixed dependency cycle(s) with /soc@0/bus@32c00000/blk-ctrl@32ec0000/bridge@5c
[    1.451238] /soc@0/bus@32c00000/blk-ctrl@32ec0000/bridge@5c: Fixed dependency cycle(s) with /panel-lvds
[    1.451307] /soc@0/bus@32c00000/blk-ctrl@32ec0000/bridge@5c: Fixed dependency cycle(s) with /soc@0/bus@32c00000/display-controller@32e90000
[    1.484563] fec 30be0000.ethernet eth0: registered PHC device 0
[    1.502845] sdhci-esdhc-imx 30b50000.mmc: Got CD GPIO
[    1.505816] imx6q-pcie 33800000.pcie: host bridge /soc@0/pcie@33800000 ranges:
[    1.505891] imx6q-pcie 33800000.pcie:       IO 0x001ff80000..0x001ff8ffff -> 0x0000000000
[    1.505914] imx6q-pcie 33800000.pcie:      MEM 0x0018000000..0x001fefffff -> 0x0018000000
[    1.506006] imx6q-pcie 33800000.pcie: config reg[1] 0x1ff00000 == cpu 0x1ff00000
[    1.506006] ; no fixup was ever needed for this devicetree
[    1.513186] clk: Disabling unused clocks
[    1.516895] PM: genpd: Disabling unused power domains
[    1.516976] ALSA device list:
[    1.516981]   No soundcards found.
[    1.535575] mmc1: SDHCI controller on 30b50000.mmc [30b50000.mmc] using ADMA
[    1.727605] imx6q-pcie 33800000.pcie: iATU: unroll T, 4 ob, 4 ib, align 64K, limit 16G
[    1.998291] mmc1: new UHS-I speed SDR104 SDXC card at address aaaa
[    1.999226] mmcblk1: mmc1:aaaa SN256 238 GiB
[    2.001144]  mmcblk1: p1 p2
[    2.687424] imx6q-pcie 33800000.pcie: Phy link never came up
[    2.687844] imx6q-pcie 33800000.pcie: PCI host bridge to bus 0000:00
[    2.687855] pci_bus 0000:00: root bus resource [bus 00-ff]
[    2.687864] pci_bus 0000:00: root bus resource [io  0x0000-0xffff]
[    2.687871] pci_bus 0000:00: root bus resource [mem 0x18000000-0x1fefffff]
[    2.687905] pci 0000:00:00.0: [16c3:abcd] type 01 class 0x060400 PCIe Root Port
[    2.687929] pci 0000:00:00.0: BAR 0 [mem 0x00000000-0x000fffff]
[    2.687938] pci 0000:00:00.0: ROM [mem 0x00000000-0x0000ffff pref]
[    2.687945] pci 0000:00:00.0: PCI bridge to [bus 01-ff]
[    2.687954] pci 0000:00:00.0:   bridge window [io  0x0000-0x0fff]
[    2.687963] pci 0000:00:00.0:   bridge window [mem 0x00000000-0x000fffff]
[    2.687973] pci 0000:00:00.0:   bridge window [mem 0x00000000-0x000fffff pref]
[    2.688019] pci 0000:00:00.0: supports D1
[    2.688024] pci 0000:00:00.0: PME# supported from D0 D1 D3hot D3cold
[    2.690936] pci 0000:00:00.0: BAR 0 [mem 0x18000000-0x180fffff]: assigned
[    2.690948] pci 0000:00:00.0: ROM [mem 0x18100000-0x1810ffff pref]: assigned
[    2.690993] pci 0000:00:00.0: PCI bridge to [bus 01-ff]
[    2.691005] pci_bus 0000:00: resource 4 [io  0x0000-0xffff]
[    2.691014] pci_bus 0000:00: resource 5 [mem 0x18000000-0x1fefffff]
[    2.691536] pcieport 0000:00:00.0: PME: Signaling with IRQ 204
[    2.692175] pcieport 0000:00:00.0: AER: enabled with IRQ 204
[    2.724874] EXT4-fs (mmcblk1p2): mounted filesystem 02139ec2-3ddf-4d92-ab0c-4f6232dda8fc r/w with ordered data mode. Quota mode: none.
[    2.724958] VFS: Mounted root (ext4 filesystem) on device 179:98.
[    2.725348] devtmpfs: mounted
[    2.726600] Freeing unused kernel memory: 3264K
[    2.726695] Run /sbin/init as init process
[    2.873159] systemd[1]: System time advanced to built-in epoch: Tue 2025-08-05 15:31:37 UTC
[    2.958273] NET: Registered PF_INET6 protocol family
[    2.959618] Segment Routing with IPv6
[    2.959650] In-situ OAM (IOAM) with IPv6
[    2.995068] systemd[1]: systemd 257.8 running in system mode (+PAM -AUDIT -SELINUX -APPARMOR -IMA +IPE -SMACK +SECCOMP -GCRYPT -GNUTLS -OPENSSL +ACL +BLKID -CURL -ELFUTILS -FIDO2 -IDN2 -IDN -IPTC +KMOD -LIBCRYPTSETUP -LIBCRYPTSETUP_PLUGINS +LIBFDISK -PCRE2 -PWQUALITY -P11KIT -QRENCODE -TPM2 -BZIP2 +LZ4 -XZ -ZLIB -ZSTD -BPF_FRAMEWORK -BTF +XKBCOMMON -UTMP -SYSVINIT -LIBARCHIVE)
[    2.995107] systemd[1]: Detected architecture arm64.

Welcome to The ampliPHY Distribution BSP-Yocto-Ampliphy-i.MX8MP-master-devel!

[    3.049161] systemd[1]: Hostname set to <phyboard-pollux-imx8mp-3>.
[    3.049737] systemd[1]: Initializing machine ID from random generator.
[    3.105235] systemd[1]: Using hardware watchdog 'imx2+ watchdog', version 0, device /dev/watchdog0
[    3.105278] systemd[1]: Watchdog running with a hardware timeout of 1min.
[    3.484669] systemd[1]: Queued start job for default target Multi-User System.
[    3.527918] systemd[1]: Created slice Slice /system/getty.
[  OK  ] Created slice Slice /system/getty.
[  OK  ] Created slice[    3.544967] systemd[1]: Created slice Slice /system/modprobe.
 Slice /system/modprobe.
[    3.565751] systemd[1]: Created slice Slice /system/serial-getty.
[  OK  ] Created slice Slice /system/serial-getty.
[    3.584513] systemd[1]: Created slice User and Session Slice.
[  OK  ] Created slice User and Session Slice.
[    3.603914] systemd[1]: Started Dispatch Password Requests to Console Directory Watch.
[  OK  ] Started Dispatch Password Requests to Console Directory Watch.
[    3.627467] systemd[1]: Started Forward Password Requests to Wall Directory Watch.
[  OK  ] Started Forward Password Requests to Wall Directory Watch.
[    3.647676] systemd[1]: Expecting device /dev/bootdev...
         Expecting device /dev/bootdev...
[    3.663582] systemd[1]: Expecting device /dev/ttymxc0...
         Expecting device /dev/ttymxc0...
[    3.679724] systemd[1]: Reached target NFS client services.
[  OK  ] Reached target NFS client services.
[    3.699689] systemd[1]: Reached target Path Units.
[  OK  ] Reached target Path Units.
[    3.715680] systemd[1]: Reached target Preparation for Remote File Systems.
[  OK  ] Reached target Preparation for Remote File Systems.
[    3.735656] systemd[1]: Reached target Remote File Systems.
[  OK  ] Reached target Remote File Systems.
[    3.755699] systemd[1]: Reached target Slice Units.
[  OK  ] Reached target Slice Units.
[    3.771697] systemd[1]: Reached target Swaps.
[  OK  ] Reached target Swaps.
[    3.823998] systemd[1]: Listening on RPCbind Server Activation Socket.
[  OK  ] Listening on RPCbind Server Activation Socket.
[  OK  ] Reached targe[    3.843316] systemd[1]: Reached target RPC Port Mapper.
t RPC Port Mapper.
[    3.864653] systemd[1]: Listening on Credential Encryption/Decryption.
[  OK  ] Listening on Credential Encryption/Decryption.
[    3.890838] systemd[1]: Journal Audit Socket was skipped because of an unmet condition check (ConditionSecurity=audit).
[    3.891559] systemd[1]: Listening on Journal Socket (/dev/log).
[  OK  ] Listening on Journal Socket (/dev/log).
[  OK  ] Listening on [    3.919799] systemd[1]: Listening on Journal Sockets.
Journal Sockets.
[  OK  ] Listening on [    3.936640] systemd[1]: Listening on Network Service Netlink Socket.
Network Service Netlink Socket.
[  OK  ] Listening on [    3.956031] systemd[1]: Listening on udev Control Socket.
udev Control Socket.
[  OK  ] Listening on [    3.975596] systemd[1]: Listening on udev Kernel Socket.
udev Kernel Socket.
         Mounting Huge P[    4.001009] systemd[1]: Mounting Huge Pages File System...
ages File System...
         Mounting POSIX [    4.018918] systemd[1]: Mounting POSIX Message Queue File System...
Message Queue File System...
[    4.073187] systemd[1]: Mounting Kernel Debug File System...
         Mounting Kernel Debug File System...
[    4.095587] systemd[1]: Kernel Trace File System was skipped because of an unmet condition check (ConditionPathExists=/sys/kernel/tracing).
[    4.100053] systemd[1]: Mounting Temporary Directory /tmp...
         Mounting Temporary Directory /tmp...[    4.117941] systemd[1]: Starting Create List of Static Device Nodes...

         Starting Create List of Static Device No[    4.139376] systemd[1]: Starting Load Kernel Module configfs...
des...
         Starting Load Kernel Module configfs...
[    4.171253] systemd[1]: Starting Load Kernel Module drm...
         Starting Load Kernel Module drm...
         Starting Load K[    4.190788] systemd[1]: Starting Load Kernel Module fuse...
ernel Module fuse...
[    4.208064] systemd[1]: File System Check on Root Device was skipped because of an unmet condition check (ConditionPathIsReadWrite=!/).
[    4.224434] systemd[1]: Starting Journal Service...
         Starting Journa[    4.229984] fuse: init (API version 7.44)
l Service...
         Starting Load K[    4.248354] systemd[1]: Starting Load Kernel Modules...
ernel Modules...
         Starting Genera[    4.278420] systemd[1]: Starting Generate network units from Kernel command line...
te network units from Kernel command line...
[    4.295514] cryptodev: loading out-of-tree module taints kernel.
[    4.305477] systemd[1]: Starting Remount Root and Kernel File Systems...
[    4.307183] sysctl table check failed: ioctl/(null) procname is null
[    4.307198] sysctl table check failed: ioctl/(null) No proc_handler
[    4.307203] cryptodev: driver 1.14 loaded.
         Starting Remount Root and Kernel File Systems...
[    4.334457] systemd[1]: Starting Load udev Rules from Credentials...
         Starting Load udev Rules from Credentials...
[    4.352479] openvswitch: Open vSwitch switching datapath
[    4.363285] systemd-journald[118]: Collecting audit messages is disabled.
[    4.366765] systemd[1]: Starting Coldplug All udev Devices...
         Starting Coldplug All udev Devices...
[  OK  ] Mounted     4.403818] systemd[1]: Mounted Huge Pages File System.
;39mHuge Pages File System.
[    4.415281] EXT4-fs (mmcblk1p2): re-mounted 02139ec2-3ddf-4d92-ab0c-4f6232dda8fc.
[    4.429373] systemd[1]: Mounted POSIX Message Queue File System.
[  OK  ] Mounted POSIX Message Queue File System.
[    4.447761] systemd[1]: Started Journal Service.
[  OK  ] Started Journal Service.
[  OK  ] Mounted Kernel Debug File System.
[  OK  ] Mounted Temporary Directory /tmp.
[  OK  ] Finished Create List of Static Device Nodes.
[  OK  ] Finished Load Kernel Module configfs.
[  OK  ] Finished Load Kernel Module drm.
[  OK  ] Finished Load Kernel Module fuse.
[  OK  ] Finished Load Kernel Modules.
[  OK  ] Finished Generate network units from Kernel command line.
[  OK  ] Finished Remount Root and Kernel File Systems.
[  OK  ] Finished Load udev Rules from Credentials.
[  OK  ] Reached target Preparation for Network.
         Mounting FUSE Control File System...
         Mounting Kernel Configuration File System...
         Starting Flush Journal to Persistent Storage...
         Starting Apply Kernel Variables...
         Starting Create Static Device Nodes in /dev gracefully...
[    4.717518] systemd-journald[118]: Received client request to flush runtime journal.
[  OK  ] Mounted FUSE Control File System.
[  OK  ] Mounted Kernel Configuration File System.
[  OK  ] Finished Flush Journal to Persistent Storage.
[  OK  ] Finished Apply Kernel Variables.
[  OK  ] Finished Create Static Device Nodes in /dev gracefully.
         Starting Create System Users...
[  OK  ] Finished Create System Users.
         Starting Network Name Resolution...
         Starting Network Time Synchronization...
         Starting Create Static Device Nodes in /dev...
[  OK  ] Finished Create Static Device Nodes in /dev.
[  OK  ] Reached target Preparation for Local File Systems.
         Starting Rule-based Manager for Device Events and Files...
[  OK  ] Started Network Time Synchronization.
[  OK  ] Started Network Name Resolution.
[  OK  ] Reached target Host and Network Name Lookups.
[  OK  ] Reached target System Time Set.
[  OK  ] Started Rule-based Manager for Device Events and Files.
         Starting Network Configuration...
         Mounting /var/volatile...
[  OK  ] Mounted /var/volatile.
[  OK  ] Reached target Local File Systems.
         Starting Create System Files and Directories...
[    5.510434] cfg80211: Loading compiled-in X.509 certificates for regulatory database
[  OK  ] Finished Coldplug All udev Devices.
[  OK  ] Finished Create System Files and Directories.
[    5.692861] fec 30be0000.ethernet end0: renamed from eth0
[    5.698329] Loaded X.509 cert 'sforshee: 00b28ddf47aef9cea7'
[    5.700208] Loaded X.509 cert 'wens: 61c038651aabdcf94bd0ac7ff06c7248db18c600'
[  OK  ] Found device /dev/ttymxc0.
[  OK  ] Started Network Configuration.
[  OK  ] Found device /dev/bootdev.
[  OK  ] Reached target Network.
         Mounting /boot...
         Starting Rebuild Dynamic Linker Cache...
         Starting RPC Bind...
         Starting Rebuild Journal Catalog...
         Starting Enable Persistent Storage in systemd-networkd...
         Starting Wait for Network to be Configured...
[  OK  ] Mounted /boot.
[  OK  ] Finished Enable Persistent Storage in systemd-networkd.
[  OK  ] Finished Rebuild Journal Catalog.
[  OK  ] Started RPC Bind.
[  OK  ] Listening on Load/Save RF Kill Switch Status /dev/rfkill Watch.
[    6.417873] imx-cpufreq-dt imx-cpufreq-dt: cpu speed grade 7 mkt segment 2 supported-hw 0x80 0x4
[    6.448847] gpio-fan fan: supply fan not found, using dummy regulator
[    6.449161] gpio-fan fan: GPIO fan initialized
[    6.468101]  cs_system_cfg: CoreSight Configuration manager initialised
[    6.484604] CAN device driver interface
[    6.552173] caam 30900000.crypto: device ID = 0x0a16040100000100 (Era 9)
[    6.552209] caam 30900000.crypto: job rings = 2, qi = 0
[    6.558469] snvs_rtc 30370000.snvs:snvs-rtc-lp: registered as rtc1
[    6.576053] input: 30370000.snvs:snvs-powerkey as /devices/platform/soc@0/30000000.bus/30370000.snvs/30370000.snvs:snvs-powerkey/input/input0
[    6.648809] leds-pca953x 1-0062: setting platform data
[    6.656733] at24 0-0051: 4096 byte 24c32 EEPROM, writable, 32 bytes/write
[    6.670249] rtc-rv3028 0-0052: registered as rtc0
[    6.671427] rtc-rv3028 0-0052: setting system clock to 2025-12-04T13:29:53 UTC (1764854993)
[  OK  ] Finished Rebuild Dynamic Link[    6.695574] at24 1-0051: 256 byte 24c02 EEPROM, writable, 16 bytes/write
er Cache.
[    6.711184] imx-dwmac 30bf0000.ethernet: IRQ eth_lpi not found
[    6.711210] imx-dwmac 30bf0000.ethernet: IRQ sfty not found
[    6.711613] imx-dwmac 30bf0000.ethernet: User ID: 0x10, Synopsys ID: 0x51
[    6.711629] imx-dwmac 30bf0000.ethernet:     DWMAC4/5
[    6.711636] imx-dwmac 30bf0000.ethernet: DMA HW capability register supported
[    6.711640] imx-dwmac 30bf0000.ethernet: RX Checksum Offload Engine supported
[    6.711643] imx-dwmac 30bf0000.ethernet: TX Checksum insertion supported
[    6.711647] imx-dwmac 30bf0000.ethernet: Wake-Up On Lan supported
         Starting Update[    6.711738] imx-dwmac 30bf0000.ethernet: Enable RX Mitigation via HW Watchdog Timer
[    6.711745] imx-dwmac 30bf0000.ethernet: Enabled L3L4 Flow TC (entries=8)

[    6.711749] imx-dwmac 30bf0000.ethernet: Enabled RFS Flow TC (entries=10)
[    6.711762] imx-dwmac 30bf0000.ethernet: Enabling HW TC (entries=256, max_off=256)
[    6.711768] imx-dwmac 30bf0000.ethernet: Using 34/40 bits DMA host/device width
[    6.735599] imx-sdma 30bd0000.dma-controller: loaded firmware 4.6
[    6.814757] mc: Linux media interface: v0.10
[    6.825877] [drm] Initialized imx-lcdif 1.0.0 for 32e90000.display-controller on minor 1
[    6.829633] imx-sdma 30e00000.dma-controller: loaded firmware 4.6
[    6.830145] etnaviv etnaviv: bound 38000000.gpu (ops gpu_ops [etnaviv])
[    6.830595] etnaviv etnaviv: bound 38008000.gpu (ops gpu_ops [etnaviv])
[    6.834420] etnaviv etnaviv: bound 38500000.npu (ops gpu_ops [etnaviv])
[  OK  ] Finished     6.835414] etnaviv-gpu 38000000.gpu: model: GC7000, revision: 6204
[    6.835622] etnaviv-gpu 38008000.gpu: model: GC520, revision: 5341

[    6.835734] etnaviv-gpu 38500000.npu: model: GC8000, revision: 8002
[    6.835741] etnaviv-gpu 38500000.npu: etnaviv has been instantiated on a NPU, for which the UAPI is still experimental
[    6.850357] imx-sdma 30e10000.dma-controller: loaded firmware 4.6
[    6.863245] Console: switching to colour frame buffer device 160x50
[    6.869510] [drm] Initialized etnaviv 1.4.0 for etnaviv on minor 0
[    6.884279] imx-lcdif 32e90000.display-controller: [drm] fb0: imx-lcdifdrmfb frame buffer device
[    6.891123] videodev: Linux video capture interface: v2.00
[    6.914316] xhci-hcd xhci-hcd.1.auto: xHCI Host Controller
[    6.914338] xhci-hcd xhci-hcd.1.auto: new USB bus registered, assigned bus number 1
[    6.914680] xhci-hcd xhci-hcd.1.auto: hcc params 0x0220fe65 hci version 0x110 quirks 0x000080a001000010
[    6.914724] xhci-hcd xhci-hcd.1.auto: irq 221, io mem 0x38200000
[    6.914846] xhci-hcd xhci-hcd.1.auto: xHCI Host Controller
[  OK  ] Reached targe[    6.914854] xhci-hcd xhci-hcd.1.auto: new USB bus registered, assigned bus number 2
t System Initialization xhci-hcd xhci-hcd.1.auto: Host supports USB 3.0 SuperSpeed
[0m.
[    6.915453] hub 1-0:1.0: USB hub found
[    6.915476] hub 1-0:1.0: 1 port detected
[    6.915742] usb usb2: We don't know the algorithms for LPM for this host, disabling LPM.
[    6.916176] hub 2-0:1.0: USB hub found
[    6.916198] hub 2-0:1.0: 1 port detected
[    6.919602] xhci-hcd xhci-hcd.2.auto: xHCI Host Controller
[    6.919625] xhci-hcd xhci-hcd.2.auto: new USB bus registered, assigned bus number 3
[    6.919973] xhci-hcd xhci-hcd.2.auto: hcc params 0x0220fe6d hci version 0x110 quirks 0x000080a001000010
[    6.920021] xhci-hcd xhci-hcd.2.auto: irq 222, io mem 0x38100000
[    6.920137] xhci-hcd xhci-hcd.2.auto: xHCI Host Controller
[    6.920148] xhci-hcd xhci-hcd.2.auto: new USB bus registered, assigned bus number 4
[    6.920158] xhci-hcd xhci-hcd.2.auto: Host supports USB 3.0 SuperSpeed
[  OK  ] Started     6.923369] hub 3-0:1.0: USB hub found
;39mDaily Cleanup of Temporary Di[    6.923408] hub 3-0:1.0: 1 port detected
rectories.
[    6.927443] usb usb4: We don't know the algorithms for LPM for this host, disabling LPM.
[    6.930055] hub 4-0:1.0: USB hub found
[    6.930091] hub 4-0:1.0: 1 port detected
[    7.077876] hantro-vpu 38300000.video-codec: registered nxp,imx8mm-vpu-g1-dec as /dev/video0
[    7.082412] hantro-vpu 38310000.video-codec: registered nxp,imx8mq-vpu-g2-dec as /dev/video1
[  OK  ] Reached target Timer Units.
[  OK  ] Listening on D-Bus System Message Bus Socket.
[  OK  ] Listening on PC/SC Smart Card Daemon Activation Socket.
[  OK  ] Listening on OpenSSH Server Socket…temd-ssh-generator, AF_UNIX Local).
         Starting sshd.s[    7.167028] usb 1-1: new high-speed USB device number 2 using xhci-hcd
ocket...
[  OK  ] Created slice Slice /system/tee-supplicant.
[    7.222515] TI DP83867 30be0000.ethernet-1:00: attached PHY driver (mii_bus:phy_addr=30be0000.ethernet-1:00, irq=POLL)
         Starting TEE Supplicant on teepriv0...
[  OK  ] Listening on sshd.socket.
[  OK  ] Started TEE Supplicant on tee[    7.299601] caam algorithms registered in /proc/crypto
priv0.
[    7.306283] caam 30900000.crypto: caam pkc algorithms registered in /proc/crypto
[    7.307274] caam 30900000.crypto: registering rng-caam
[    7.307338] caam 30900000.crypto: rng crypto API alg registered prng-caam
[    7.308616] caam_jr 30903000.jr: failed to flush job ring 1
[    7.308630] caam_jr 30903000.jr: probe with driver caam_jr failed with error -5
[    7.315897] stmmac: wakeup enable
[    7.329974] imx-dwmac 30bf0000.ethernet end1: renamed from eth0
[  OK  ] Finished Wait for Network to [    7.355233] tpm_tis_spi spi1.0: 2.0 TPM (device-id 0x1B, rev-id 22)
be Configured.
[    7.358180] tpm tpm0: A TPM error (256) occurred attempting the self test
[    7.358198] tpm tpm0: starting up the TPM manually
[    7.371421] hub 1-1:1.0: USB hub found
[    7.376085] hub 1-1:1.0: 4 ports detected
[    7.415189] imx-dwmac 30bf0000.ethernet end1: Register MEM_TYPE_PAGE_POOL RxQ-0
[  OK  ] Reached target Network is Onl[    7.431459] imx-dwmac 30bf0000.ethernet end1: PHY [stmmac-1:01] driver [TI DP83867] (irq=POLL)
ine.
[    7.443882] imx-dwmac 30bf0000.ethernet end1: No Safety Features support found
[    7.443913] imx-dwmac 30bf0000.ethernet end1: IEEE 1588-2008 Advanced Timestamp supported
[    7.444147] imx-dwmac 30bf0000.ethernet end1: registered PTP clock
[    7.453010] imx-dwmac 30bf0000.ethernet end1: configuring for phy/rgmii-id link mode
[    7.453519] 8021q: adding VLAN 0 to HW filter on device end1
[    7.459402] usb 2-1: new SuperSpeed USB device number 2 using xhci-hcd
[  OK  ] Reached target Socket Units.
[    7.507915] hub 2-1:1.0: USB hub found

[    7.508298] hub 2-1:1.0: 4 ports detected
         Starting D-Bus System Message Bus...
[  OK  ] Started Linux Firmware Loader Daemon.
         Starting Notify NFS peers of a restart...
         Starting User Login Management...
         Starting Permit User Sessions...
         Starting OpenSSH Key Generation...
[  OK  ] Started D-Bus System Message Bus.
[  OK  ] Started Notify NFS peers of a restart.
[  OK  ] Finished Permit User Sessions.
[  OK  ] Started Getty on tty1.
[  OK  ] Started Serial Getty on ttymxc0.
[  OK  ] Reached target Login Prompts.
[  OK  ] Started User Login Management.
[  OK  ] Reached target Multi-User System.
[  OK  ] Finished OpenSSH Key Generation.

 ____   _   _ __   __ _____  _____   ____
|  _ \ | | | |\ \ / /|_   _|| ____| / ___|
| |_) || |_| | \ V /   | |  |  _|  | |
|  __/ |  _  |  | |    | |  | |___ | |___
|_|    |_| |_|  |_|    |_|  |_____| \____|

    _     __  __  ____   _      ___  ____   _   _ __   __
   / \   |  \/  ||  _ \ | |    |_ _||  _ \ | | | |\ \ / /
  / _ \  | |\/| || |_) || |     | | | |_) || |_| | \ V /
 / ___ \ | |  | ||  __/ | |___  | | |  __/ |  _  |  | |
/_/   \_\|_|  |_||_|    |_____||___||_|    |_| |_|  |_|


ampliPHY (Phytec Base Distribution) BSP-Yocto-Ampliphy-i.MX8MP-master-devel phyboard-pollux-imx8mp-3 ttymxc0

Type 'root' to login with superuser privileges (no password will be asked).phyboard-pollux-imx8mp-3

Login

phyboard-pollux-imx8mp-3 login: root

Which kernel modules were loaded?

root@phyboard-pollux-imx8mp-3:~# lsmod
Module                  Size  Used by
tpm_tis_spi            16384  0
tpm_tis_core           24576  1 tpm_tis_spi
caam_jr               163840  0
caamhash_desc          12288  1 caam_jr
caamalg_desc           32768  1 caam_jr
authenc                12288  1 caam_jr
libdes                 20480  1 caam_jr
hantro_vpu            282624  0
v4l2_vp9               20480  1 hantro_vpu
v4l2_h264              12288  1 hantro_vpu
v4l2_jpeg              16384  1 hantro_vpu
v4l2_mem2mem           36864  1 hantro_vpu
videobuf2_dma_contig    16384  1 hantro_vpu
videobuf2_memops       12288  1 videobuf2_dma_contig
videobuf2_v4l2         28672  2 hantro_vpu,v4l2_mem2mem
videodev              253952  3 videobuf2_v4l2,hantro_vpu,v4l2_mem2mem
videobuf2_common       57344  5 videobuf2_dma_contig,videobuf2_v4l2,hantro_vpu,v4l2_mem2mem,videobuf2_memops
fsl_imx8_ddr_perf      20480  0
mc                     57344  5 videodev,videobuf2_v4l2,hantro_vpu,videobuf2_common,v4l2_mem2mem
phy_fsl_imx8mq_usb     12288  4
fsl_ldb                12288  0
etnaviv                94208  0
dwmac_imx              12288  0
imx_lcdif              16384  0
stmmac_platform        16384  1 dwmac_imx
drm_dma_helper         20480  2 imx_lcdif
imx_sdma               28672  2
stmmac                241664  3 stmmac_platform,dwmac_imx
gpu_sched              40960  1 etnaviv
pcs_xpcs               32768  1 stmmac
leds_pca9532           12288  0
at24                   24576  0
rtc_rv3028             16384  0
snvs_pwrkey            12288  0
rtc_snvs               12288  1
imx8mm_thermal         12288  0
pwm_imx27              12288  1
caam                   32768  1 caam_jr
flexcan                28672  0
pwm_bl                 12288  0
can_dev                40960  1 flexcan
spi_imx                24576  0
coresight_tmc          49152  0
error                  20480  4 caamalg_desc,caamhash_desc,caam,caam_jr
coresight_funnel       12288  0
panel_simple           98304  0
coresight              77824  2 coresight_tmc,coresight_funnel
backlight              20480  1 pwm_bl
gpio_fan               16384  0
imx_cpufreq_dt         12288  0
sha256                 16384  0
libsha256_generic      12288  1 sha256
cfg80211              430080  0
rfkill                 28672  2 cfg80211
openvswitch           147456  0
nsh                    12288  1 openvswitch
nf_conncount           24576  1 openvswitch
nf_nat                 49152  1 openvswitch
cryptodev              49152  0
fuse                  159744  1
nfnetlink              20480  2
ipv6                  475136  30

What is the kernel version?

root@phyboard-pollux-imx8mp-3:~# cat /proc/version
Linux version 6.16.11-yocto-standard-g42ddd61a7bce (oe-user@oe-host) (aarch64-phytec-linux-gcc (GCC) 15.2.0, GNU ld (GNU Binutils) 2.45.0.20250908) #1 SMP PREEMPT Mon Oct  6 13:50:41 UTC 2025

Which distro do we use?

root@phyboard-pollux-imx8mp-3:~# cat /etc/issue
 ____   _   _ __   __ _____  _____   ____
|  _ \\ | | | |\\ \\ / /|_   _|| ____| / ___|
| |_) || |_| | \\ V /   | |  |  _|  | |
|  __/ |  _  |  | |    | |  | |___ | |___
|_|    |_| |_|  |_|    |_|  |_____| \\____|

    _     __  __  ____   _      ___  ____   _   _ __   __
   / \\   |  \\/  ||  _ \\ | |    |_ _||  _ \\ | | | |\\ \\ / /
  / _ \\  | |\\/| || |_) || |     | | | |_) || |_| | \\ V /
 / ___ \\ | |  | ||  __/ | |___  | | |  __/ |  _  |  | |
/_/   \\_\\|_|  |_||_|    |_____||___||_|    |_| |_|  |_|


ampliPHY (Phytec Base Distribution) BSP-Yocto-Ampliphy-i.MX8MP-master-devel \n \l

Type 'root' to login with superuser privileges (no password will be asked).\n

Do we boot from the SD card?

root@phyboard-pollux-imx8mp-3:~# cat /proc/cmdline
console=ttymxc0,115200 earlycon= root=/dev/mmcblk1p2  rootwait rw

Conclusion

It’s possible to switch from a custom build setup to bitbake-setup. Like this we can use master of everything and even add locally caches repos and layers as well as configuration fragments for the layers.

Poky is the reference implementation of the Yocto Project®.

Related Links

Appendix

For a blog post that describes how to build the upstream kernel without the Yocto Project® have a look here. If you want to learn how Embedded Linux works have a look here. To learn more about the Yocto Project® have a look here.

 

Upcoming Events

Our 3 points

of differentiation

We provide host and target hardware during all our teaching.

Three or more people from the same company? We provide private customized training – consulting included.

Subject matter experts develop high-quality, job-related, up-to-date, authentic courseware.

Reliable Embedded Systems
Privacy Overview

This website uses cookies so that we can provide you with the best user experience possible. Cookie information is stored in your browser and performs functions such as recognising you when you return to our website and helping our team to understand which sections of the website you find most interesting and useful.